.. Copyright 2011, 2012, 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Reahl documentation
===================

Reahl is a web application framework that allows a programmer to work
in terms of useful abstractions -- using a single programming language.

The details of how those abstractions are implemented using several
different web technologies are hidden and dealt with for the
programmer.

Contents:

.. toctree::
   :maxdepth: 1

   overview
   features/index
   tutorial/gettingstarted
   tutorial/index
   component/index
   web/index
   domain/index
   devtools/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

